<?php

/*
 * LMS version 1.5.0 Marduk
 *
 *  (C) Copyright 2001-2004 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: checkdirs.php,v 1.22 2004/09/18 19:21:18 alec Exp $
 */

if(!is_dir($_SMARTY_COMPILE_DIR))
	die('Brakuje mi katalogu <B>'.$_SMARTY_COMPILE_DIR.'</B> - bd wdziczny jak kto go utworzy.');

if(!is_writable($_SMARTY_COMPILE_DIR))
	die('Nie mog zapisywa do katalogu <B>'.$_SMARTY_COMPILE_DIR.'</B> - mgby wykona komend:<BR><pre>chown '.posix_geteuid().'.'.posix_getegid().' '.$_SMARTY_COMPILE_DIR."\nchmod 755 ".$_SMARTY_COMPILE_DIR.'</pre><BR>Pomoe mi to poprawnie dziaa. Dziki.');

if(!is_dir($_BACKUP_DIR))
	die('Brakuje mi katalogu <B>'.$_BACKUP_DIR.'</B> - bd wdziczny jak kto6 go utworzy.');
	
if(!is_writable($_BACKUP_DIR))
	die('Nie mog zapisywa do katalogu <B>'.$_BACKUP_DIR.'</B> - mgby wykona komend:<BR><pre>chown '.posix_geteuid().'.'.posix_getegid().' '.$_BACKUP_DIR."\nchmod 755 ".$_BACKUP_DIR.'</pre><BR>Pomoe mi to poprawnie dziaa. Dziki.');

?>
